def get_http(event):
    if not event.get('headers'):
        return None
    host = event['headers'].get('Host') or event['headers'].get('host')
    useragent = event['headers'].get('User-Agent') or event['headers'].get('user-agent')
    return {
        'url': f"https://{host}{event['path']}",
        'useragent': useragent,
        'method': event['httpMethod'],
        'host': host
    }


def remove_empty_keys(data):
    obj = data
    if not isinstance(data, dict) or not data:
        return data
    for key in obj.keys():
        if obj[key] and isinstance(obj[key], dict):
            remove_empty_keys(obj[key])
        elif obj[key] is None:
            del obj[key]
    return obj


import json
import base64

def getUserPayload(event):
    headers = event.get('headers')
    if not headers:
        return None
    authorization = headers.get('Authorization') or headers.get('authorization')
    if not authorization:
        return None
    payload = authorization.split('.')[1]
    if not payload:
        return None
    try:
        return json.loads(base64.b64decode(payload).decode('utf-8'))
    except:
        return None

def get_user(event):
    requestContext = event.get('requestContext')
    if not requestContext:
        return None
    context = requestContext.get('authorizer')
    payload = getUserPayload(event)
    if not payload:
        return None
    return {
        'id': payload.get('sub'),
        'status': context.get('status'),
        'groups': payload.get('groups') or payload.get('cognito:groups'),
        'email': payload.get('email'),
        'type': context.get('type') or payload.get('type'),
        'companyId': context.get('companyId'),
        'scope': payload.get('scope')
    }


def get_ip(event):
    try:
        requestContext = event.get('requestContext', {})
        identity = requestContext.get('identity', {})
        sourceIp = identity.get('sourceIp')
    except:
        sourceIp = None
    headers = event.get('headers')
    if headers:
        ip = headers.get('CF-Connecting-IP') or headers.get('cf-connecting-ip') \
            or headers.get('X-Real-IP') or headers.get('x-real-ip') \
            or headers.get('X-Forwarded-For') or headers.get('x-forwarded-for')
    else:
        ip = sourceIp
    if not ip:
        return None
    return ip.split(',')[0]